# HISTORY

### 2019-11-27
* Add `--no-terminal-constraint` option (Default False) to support bounded Terminal version
of KunDB and ArgoDB. This feature is enabled by default since v1.3.5.
For pre TDC-2.1, we should explicitly run
```bash
verminator validate --no-terminal-constraint instances
```
Or constraint the dependencies as `verminator<1.3.5`.